import { motion } from "framer-motion";
import { fadeIn, staggerContainer } from "@/lib/animation";
import { FaChevronDown } from "react-icons/fa";
import { useEffect, useState } from "react";

const Hero = () => {
  const [loaded, setLoaded] = useState(false);

  useEffect(() => {
    setLoaded(true);
  }, []);

  const bounceAnimation = {
    y: [0, -10, 0],
    transition: {
      duration: 1.5,
      repeat: Infinity,
      repeatType: "loop" as const
    }
  };
  
  // Direct navigation method
  const scrollToWhatIs = () => {
    try {
      const whatIsSection = document.getElementById('what-is');
      if (whatIsSection) {
        whatIsSection.scrollIntoView({ 
          behavior: 'smooth',
          block: 'start'
        });
        console.log("DIRECT SCROLL to what-is");
      } else {
        console.error("What-is section not found!");
      }
    } catch (err) {
      console.error("Scroll error:", err);
    }
  };

  return (
    <section className="pt-32 pb-16 md:pt-36 md:pb-28 relative overflow-hidden w-full min-h-[90vh] flex flex-col justify-between prevent-overflow">
      <div className="absolute inset-0 bg-gradient-to-br from-indigo-50 to-purple-50 z-0"></div>
      <div className="absolute inset-0 w-full h-full bg-[url('https://images.unsplash.com/photo-1607799279861-4dd421887fb3?ixlib=rb-1.2.1&auto=format&fit=crop&w=1920&q=80')] bg-no-repeat bg-cover bg-center opacity-5 z-0"></div>
      
      <motion.div 
        variants={staggerContainer}
        initial="hidden"
        animate="show"
        className="container mx-auto px-4 md:px-6 lg:px-8 relative z-10 flex-grow flex flex-col justify-center mt-10 sm:mt-0 overflow-hidden"
        style={{ overscrollBehaviorX: 'none' }}
      >
        <div className="max-w-3xl mx-auto md:text-center w-full">
          <motion.h1 
            variants={fadeIn("up", "tween", 0.2, 1)}
            className="text-3xl md:text-5xl lg:text-6xl font-bold leading-tight mb-4 md:mb-6 break-words"
          >
            Turn Your Ideas into Real Apps in Just 12 Weeks
            <span className="block md:inline bg-clip-text text-transparent bg-gradient-to-r from-purple-500 to-blue-500 mt-2 md:mt-0 md:ml-2">—Zero Coding Experience Required</span>
          </motion.h1>
          
          <motion.h2
            variants={fadeIn("up", "tween", 0.25, 1)}
            className="text-xl md:text-3xl font-bold text-gray-800 mb-3 md:mb-4 break-words"
          >
            Expert coaching + AI tools to build real apps without coding
          </motion.h2>
          
          <motion.p 
            variants={fadeIn("up", "tween", 0.3, 1)}
            className="text-lg md:text-2xl text-gray-700 mb-8 md:mb-12 break-words max-w-full overflow-hidden"
          >
            12 weeks of personalized support to turn your ideas into working software.
          </motion.p>
          
          <motion.div 
            variants={fadeIn("up", "tween", 0.4, 1)}
            className="flex flex-col md:flex-row md:justify-center gap-4 mb-12"
          >
            <button 
              className="bg-gradient-to-r from-purple-500 to-blue-500 text-white font-medium px-8 py-4 rounded-lg shadow-lg hover:shadow-xl transition-all transform hover:-translate-y-0.5 text-center text-lg cursor-pointer inline-block"
              onClick={scrollToWhatIs}
            >
              Start Your Journey
            </button>
          </motion.div>
          
          <motion.div 
            variants={fadeIn("up", "tween", 0.5, 1)}
            className="bg-white/80 backdrop-blur-sm p-6 rounded-xl shadow-lg w-full overflow-hidden"
          >
            <p className="text-gray-600 font-medium mb-2">Perfect for:</p>
            <div className="flex flex-wrap justify-center gap-2 sm:gap-3">
              <span className="bg-indigo-100 text-indigo-800 px-3 py-1 rounded-full text-sm whitespace-nowrap">Entrepreneurs</span>
              <span className="bg-purple-100 text-purple-800 px-3 py-1 rounded-full text-sm whitespace-nowrap">Remote Workers</span>
              <span className="bg-blue-100 text-blue-800 px-3 py-1 rounded-full text-sm whitespace-nowrap">Designers</span>
              <span className="bg-pink-100 text-pink-800 px-3 py-1 rounded-full text-sm whitespace-nowrap">Students</span>
              <span className="bg-indigo-100 text-indigo-800 px-3 py-1 rounded-full text-sm whitespace-nowrap">App Creators</span>
            </div>
          </motion.div>
        </div>
      </motion.div>
      
      {/* Bouncing Arrow */}
      {loaded && (
        <div className="w-full flex justify-center pb-8 mt-8">
          <div onClick={scrollToWhatIs} className="cursor-pointer">
            <motion.div 
              animate={bounceAnimation}
              className="flex flex-col items-center cursor-pointer group"
            >
              <span className="text-sm text-gray-600 font-medium mb-2 group-hover:text-indigo-600 transition-colors">
                Scroll Down
              </span>
              <FaChevronDown className="text-2xl text-indigo-500 group-hover:text-indigo-600 transition-colors" />
            </motion.div>
          </div>
        </div>
      )}
    </section>
  );
};

export default Hero;
